@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef LINEEDITCATCHRETURNKEY_H
 #define LINEEDITCATCHRETURNKEY_H
 
-#include <QObject>
 #include "kdepim_export.h"
+#include <QObject>
 class QLineEdit;
-namespace KPIM {
+namespace KPIM
+{
 /**
  * @brief The LineEditCatchReturnKey class
  * @author Laurent Montel <montel@kde.org>
@@ -20,7 +21,7 @@ class KDEPIM_EXPORT LineEditCatchReturnKey : public QObject
     Q_OBJECT
 public:
     explicit LineEditCatchReturnKey(QLineEdit *lineEdit, QObject *parent = nullptr);
-    ~LineEditCatchReturnKey();
+    ~LineEditCatchReturnKey() override;
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
